diff --git a/include/FLAC/format.h b/include/FLAC/format.h
index 7424565..1b19d42 100644
--- a/include/FLAC/format.h
+++ b/include/FLAC/format.h
@@ -512,8 +512,8 @@ typedef enum {
 	FLAC__METADATA_TYPE_UNDEFINED = 7,
 	/**< marker to denote beginning of undefined type range; this number will increase as new metadata types are added */
 
-        FLAC__MAX_METADATA_TYPE = FLAC__MAX_METADATA_TYPE_CODE,
-        /**< No type will ever be greater than this. There is not enough room in the protocol block. */
+	FLAC__MAX_METADATA_TYPE = FLAC__MAX_METADATA_TYPE_CODE,
+	/**< No type will ever be greater than this. There is not enough room in the protocol block. */
 } FLAC__MetadataType;
 
 /** Maps a FLAC__MetadataType to a C string.
diff --git a/src/flac/encode.c b/src/flac/encode.c
index 5408548..030409c 100644
--- a/src/flac/encode.c
+++ b/src/flac/encode.c
@@ -2480,7 +2480,7 @@ FLAC__StreamDecoderReadStatus flac_decoder_read_callback(const FLAC__StreamDecod
 {
 	size_t n = 0;
 	EncoderSession *e = (EncoderSession*)client_data;
-    FLACDecoderData *data = &e->fmt.flac.client_data;
+	FLACDecoderData *data = &e->fmt.flac.client_data;
 
 	(void)decoder;
 
@@ -2538,7 +2538,7 @@ FLAC__StreamDecoderTellStatus flac_decoder_tell_callback(const FLAC__StreamDecod
 FLAC__StreamDecoderLengthStatus flac_decoder_length_callback(const FLAC__StreamDecoder *decoder, FLAC__uint64 *stream_length, void *client_data)
 {
 	const EncoderSession *e = (EncoderSession*)client_data;
-    const FLACDecoderData *data = &e->fmt.flac.client_data;
+	const FLACDecoderData *data = &e->fmt.flac.client_data;
 	(void)decoder;
 
 	if(data->filesize < 0)
@@ -2560,7 +2560,7 @@ FLAC__bool flac_decoder_eof_callback(const FLAC__StreamDecoder *decoder, void *c
 FLAC__StreamDecoderWriteStatus flac_decoder_write_callback(const FLAC__StreamDecoder *decoder, const FLAC__Frame *frame, const FLAC__int32 * const buffer[], void *client_data)
 {
 	EncoderSession *e = (EncoderSession*)client_data;
-    FLACDecoderData *data = &e->fmt.flac.client_data;
+	FLACDecoderData *data = &e->fmt.flac.client_data;
 	FLAC__uint64 n = min(data->samples_left_to_process, frame->header.blocksize);
 	(void)decoder;
 
@@ -2577,7 +2577,7 @@ FLAC__StreamDecoderWriteStatus flac_decoder_write_callback(const FLAC__StreamDec
 void flac_decoder_metadata_callback(const FLAC__StreamDecoder *decoder, const FLAC__StreamMetadata *metadata, void *client_data)
 {
 	EncoderSession *e = (EncoderSession*)client_data;
-    FLACDecoderData *data = &e->fmt.flac.client_data;
+	FLACDecoderData *data = &e->fmt.flac.client_data;
 	(void)decoder;
 
 	if (data->fatal_error)
@@ -2595,7 +2595,7 @@ void flac_decoder_metadata_callback(const FLAC__StreamDecoder *decoder, const FL
 void flac_decoder_error_callback(const FLAC__StreamDecoder *decoder, FLAC__StreamDecoderErrorStatus status, void *client_data)
 {
 	EncoderSession *e = (EncoderSession*)client_data;
-    FLACDecoderData *data = &e->fmt.flac.client_data;
+	FLACDecoderData *data = &e->fmt.flac.client_data;
 	(void)decoder;
 
 	stats_print_name(1, e->inbasefilename);
diff --git a/src/libFLAC/include/private/macros.h b/src/libFLAC/include/private/macros.h
index b72b69b..d00e772 100644
--- a/src/libFLAC/include/private/macros.h
+++ b/src/libFLAC/include/private/macros.h
@@ -35,16 +35,16 @@
 #if defined(__GNUC__) && (__GNUC__ > 4 || ( __GNUC__ == 4 && __GNUC_MINOR__ >= 3))
 
 #define flac_max(a,b) \
-    ({ __typeof__ (a) _a = (a); \
-    __typeof__ (b) _b = (b); \
-    _a > _b ? _a : _b; })
+	({ __typeof__ (a) _a = (a); \
+	__typeof__ (b) _b = (b); \
+	_a > _b ? _a : _b; })
 
 #define MIN_PASTE(A,B) A##B
 #define MIN_IMPL(A,B,L) ({ \
-    __typeof__(A) MIN_PASTE(__a,L) = (A); \
-    __typeof__(B) MIN_PASTE(__b,L) = (B); \
-    MIN_PASTE(__a,L) < MIN_PASTE(__b,L) ? MIN_PASTE(__a,L) : MIN_PASTE(__b,L); \
-    })
+	__typeof__(A) MIN_PASTE(__a,L) = (A); \
+	__typeof__(B) MIN_PASTE(__b,L) = (B); \
+	MIN_PASTE(__a,L) < MIN_PASTE(__b,L) ? MIN_PASTE(__a,L) : MIN_PASTE(__b,L); \
+	})
 
 #define flac_min(A,B) MIN_IMPL(A,B,__COUNTER__)
 
diff --git a/src/libFLAC/lpc.c b/src/libFLAC/lpc.c
index 5c6e175..882862c 100644
--- a/src/libFLAC/lpc.c
+++ b/src/libFLAC/lpc.c
@@ -59,7 +59,7 @@
 #define copysign __builtin_copysign
 #endif
 static inline long int lround(double x) {
-    return (long)(x + copysign (0.5, x));
+	return (long)(x + copysign (0.5, x));
 }
 /* If this fails, we are in the presence of a mid 90's compiler, move along... */
 #endif
diff --git a/src/share/grabbag/replaygain.c b/src/share/grabbag/replaygain.c
index 0573096..a1691c7 100644
--- a/src/share/grabbag/replaygain.c
+++ b/src/share/grabbag/replaygain.c
@@ -117,7 +117,7 @@ static FLAC__bool append_tag_(FLAC__StreamMetadata *block, const char *format, c
 
 FLAC__bool grabbag__replaygain_is_valid_sample_frequency(unsigned sample_frequency)
 {
-        return ValidGainFrequency( sample_frequency );
+	return ValidGainFrequency( sample_frequency );
 }
 
 FLAC__bool grabbag__replaygain_init(unsigned sample_frequency)
diff --git a/src/test_grabbag/picture/main.c b/src/test_grabbag/picture/main.c
index a21f3d6..61baf6e 100644
--- a/src/test_grabbag/picture/main.c
+++ b/src/test_grabbag/picture/main.c
@@ -57,12 +57,12 @@ static FLAC__bool debug_ = false;
 
 static FLAC__bool failed_(const char *msg)
 {
-    if(msg)
-        printf("FAILED, %s\n", msg);
-    else
-        printf("FAILED\n");
+	if(msg)
+		printf("FAILED, %s\n", msg);
+	else
+		printf("FAILED\n");
 
-    return false;
+	return false;
 }
 
 static FLAC__bool test_one_picture(const char *prefix, const PictureFile *pf, const PictureResolution * res, FLAC__bool fn_only)
@@ -122,7 +122,7 @@ static FLAC__bool do_picture(const char *prefix)
 	const char *error;
 	size_t i;
 
-    printf("\n+++ grabbag unit test: picture\n\n");
+	printf("\n+++ grabbag unit test: picture\n\n");
 
 	/* invalid spec: no filename */
 	printf("testing grabbag__picture_parse_specification(\"\")... ");
